@@ -12,7 +12,8 @@ fi
 #fi
 
 if [ ! -d /sys/firmware/efi/efivars ]; then
-    sudo sed -i -e 's|"xfs","ext4","zfs"|"xfs","ext4"|' /usr/share/calamares/modules/partition.conf
+    sudo sed -i -e 's|"xfs","ext4","zfs"|"ext4"|' /usr/share/calamares/modules/partition.conf
+    sudo sed -i -e 's|defaultFileSystemType:  "xfs"|defaultFileSystemType:  "ext4"|' /usr/share/calamares/modules/partition.conf
 fi
 
 sudo /usr/bin/calamares -d > installation.log
